#
# spec file for package rustscan
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2020, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rustscan
Version:        2.3.0+0
Release:        1.1
Summary:        Fast network port scanner
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Diagnostic
URL:            https://github.com/RustScan/RustScan
Source:         RustScan-%{version}.tar.xz
Source1:        vendor.tar.xz
BuildRequires:  cargo-packaging
BuildRequires:  python3
Recommends:     nmap

%description
Find all open ports fast with RustScan, then automatically
pipe them into Nmap.

%prep
%setup -qa1 -n RustScan-%{version}

%build
%{cargo_build}

%install
%{cargo_install}

%check
%{cargo_test} -- \
  --skip address::tests::parse_correct_host_addresses \
  --skip address::tests::parse_hosts_file_and_incorrect_hosts \
  --skip address::tests::resolver_args_google_dns \
  --skip address::tests::resolver_default_cloudflare

%files
%license LICENSE
%doc README.md
%{_bindir}/rustscan

%changelog
* Sun Oct 13 2024 Andrea Manzini <andrea.manzini@suse.com>
- update to 2.3.0:
  * Udp Scanning (#596) @BrendanGlancy
  * feat(cli): add custom dns resolver option (#587)
  * bump dependencies
- update to 2.2.2:
  * enabling exclude port list capability Issue #530 (#534)
    You can now exclude ports from being scanned.
  * RustScan now supports ARM based devices
- dropped cargo_config
- added %%check section to run testsuite (excluding those needing network)
* Sat Jan 20 2024 Andreas Stieger <andreas.stieger@gmx.de>
- Downgrade nmap requirements to recommends: The no-nmap option
  exists, and nmap should move to :NonFree
* Wed Jun 14 2023 Robert Frohl <rfrohl@suse.com>
- Drop not needed RustScan-*.obscpio, as RustScan-*.tar.xz is used
  for build the package.
* Sat Dec  3 2022 Dirk Müller <dmueller@suse.com>
- update to 2.1.1:
  * Minor cosmetic changes
  * fix links to Docker & Kali wiki
  * Upgrade rlimit
  * Improve doc for addresses
  * Allow CLI customisation of config file path
  * Supports M1 Macs tada
  * Partially fix #362: Fix examples (#363)
  * Scripting engine arguments. Scan engine errors.
* Mon Jun 20 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Tue May 24 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Fri Jan  7 2022 William Brown <william.brown@suse.com>
- resolve bsc#1194119 (CVE-2021-45710)
- Add cargo_vendor service to assist with updates
- Use cargo-packaging and relevant macros to improve spec
* Fri Nov  5 2021 William Brown <william.brown@suse.com>
- Add cargo audit service to detect potential security issues
* Fri Nov  6 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.0.1
  Features
  * Scripting Engine Implementation.
  * Improved init_scripts error handling.
  * Add tries to scan_socket.
  * Make address an optional instead of a positional argument.
  Maintenance
  * Add tests for rustscan scripting engine.
  * Add clippy linting and fix existing warnings.
  Bugs
  * Changed the dns resolving to use std::net::ToSocketAddrs.
  * Fix Rlimit breaking change.
  * Update documentation to include greppable.
* Tue Sep 29 2020 Martin Hauke <mardnh@gmx.de>
- Update to versino 1.10.0
  Features
  * Added DNS lookup using Google DNS, refactored IP code.
  * Take file of addresses as input.
  Maintenance
  * Refactored tests, introduced default function in test context
    for structs.
* Fri Aug 28 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.8.0
  Features
  * Allow randomised order for manual ports.
  * Add --port and --range options.
  * Added host resolution.
  * Added accessible mode.
  * Added port scanning strategy.
  Maintenance
  * Added the Git submodule for RustScan Scripting Engine
  * Removed -A from Nmap.
  * Added top 1k ports in config file.
  * Excluded unnecessary files.
  Fixed bugs
  * GH#169, GH#165, GH#163, GH#153
* Sun Aug  9 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.7.1
  Features
  * New terminal user interface. Much prettier and easier to read
  * Port randomisation (so it's not a sequential hit of multiple
    ports)
  Maintenance
  * Created macros to easily report information back to the user
  * Reduced size of error messages (boy were they long smirk_cat )
  * More tests
- Update to version 1.6.0
  * Added multiple IP support. This is in extremely early stage,
    but it works.
  Maintenance
  * Fixed help menu bugs and quiet mode not working bugs.
* Tue Aug  4 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.5.2
  * Added --appdirs flag to find the appdirs location.
  * Refactored batch size to fix #58.
  * Fixed bug where appdirs wasn't pointing to the complete
    directory.
  * Fixed bug where automatic ulimit lowering wasn't working on
    systems with extremely low ulimits (< 250).
* Sat Aug  1 2020 Martin Hauke <mardnh@gmx.de>
- Initial package, version 1.4.0
